Disaggregation of other land into initial, restored and recovered land based on a MAgPIE gdx file
Examples
if (FALSE) { # \dontrun{
x <- PeatlandArea(gdx)
} # }
Disaggregation of other land into initial, restored and recovered land based on a MAgPIE gdx file
if (FALSE) { # \dontrun{
x <- PeatlandArea(gdx)
} # }