Skip to content

Reads potential yields after calibration

Usage

YieldsCropCalib(gdx, file = NULL, level = "cell", tau = FALSE)

Arguments

gdx

GDX file

file

a file name the output should be written to using write.magpie

level

Level of regional aggregation

tau

if TRUE add effect of TAU to the yield

Value

A MAgPIE object containing values of potential yields after the calibration routines

Author

Edna Molina Bacca

Examples

if (FALSE) { # \dontrun{
x <- YieldsCropCalib(gdx)
} # }