Skip to content

Reads potential yields after calibration

Usage

YieldsCropRaw(gdx, file = NULL, level = "cell")

Arguments

gdx

GDX file

file

a file name the output should be written to using write.magpie

level

Level of regional aggregation

Value

A MAgPIE object containing values of potential yields after the calibration routines

Author

Edna Molina Bacca

Examples

if (FALSE) { # \dontrun{
x <- YieldsCropRaw(gdx)
} # }