Returns the years to put into the data changelog, see addToDataChangelog.
See also
Other Data Changelog:
addToDataChangelog(),
changelogVariables()
Returns the years to put into the data changelog, see addToDataChangelog.
Other Data Changelog:
addToDataChangelog(),
changelogVariables()