Skip to content

Collects reports for Steven Lord's cost of action / cost of inaction analysis.

Usage

getReportFSECStevenLord(gdx, reportOutputDir, scenario)

Arguments

gdx

gdx file

reportOutputDir

a folder name for the output to be written to. If NULL the report is not saved to disk, and only returned to the calling function.

scenario

the name of the scenario used. If NULL the report is not saved to disk, and only returned to the calling function.

Author

Michael Crawford

Examples


  if (FALSE) { # \dontrun{
    x <- getReportFSECStevenLord()
  } # }