reads and compiles forestry land subcategories from a MAgPIE gdx file
Examples
if (FALSE) { # \dontrun{
x <- land(gdx)
} # }
reads and compiles forestry land subcategories from a MAgPIE gdx file
if (FALSE) { # \dontrun{
x <- land(gdx)
} # }