Skip to content

Function to safely returns parameters. Function returns either the output or writes it to a file. Please use this function when you write own GDX output functions.

Usage

out(x,file)

Arguments

x

an object that can be converted to a MAgPIE object

file

file name of a file it should be written to. NULL, if x should be returned instead to be written to a file.

Value

NULL or x as MAgPIE object

Author

Jan Philipp Dietrich