Skip to content

reports demand for bioplastic and demand for substrate for bioplastic production from MAgPIE results

Usage

reportBioplasticDemand(gdx, detail = TRUE, level = "regglo")

Arguments

gdx

GDX file

detail

only relevant for substrate demand. If TRUE, substrate demand is disaggregated by crop type, if FALSE only the aggregated demand is reported.

level

spatial aggregation to report bioplastic/substrate demand (only "reg" or "regglo")

Value

bioplastic and bioplastic substrate demand as MAgPIE object

Bioplastic demand variables

NameUnitMeta
Demand for bioplasticMt/yrTotal bioplastic demand
Demand for bioplastic substrate|TotalMt DM/yrTotal substrate demand for bioplastic production

Author

Debbora Leip

Examples


  if (FALSE) { # \dontrun{
    x <- reportBioplasticDemand(gdx)
  } # }