Skip to content

reports croparea

Usage

reportCroparea(gdx, detail = FALSE, level = "regglo")

Arguments

gdx

GDX file

detail

if detail=FALSE, the subcategories of groups are not reported (e.g. "soybean" within "oilcrops")

level

aggregation level of returned data ("regglo" by default)

Value

Croparea as MAgPIE object (million ha/yr)

Croparea variables

NameUnitMeta
Resources|Land Cover|Cropland|Cropareamillion haTotal physical cropland area used for crop production
Resources|Land Cover|Cropland|Croparea|+|Cropsmillion haCropland area for food and feed crops
Resources|Land Cover|Cropland|Croparea|Crops|+|Cerealsmillion haCropland for cereals (maize, rice, temperate cereals and tropical cereals)
Resources|Land Cover|Cropland|Croparea|Crops|+|Oil cropsmillion haCropland for oil crops (cotton seed, groundnuts, oilpalms, other oil crops, soybean, sunflower)
Resources|Land Cover|Cropland|Croparea|Crops|+|Sugar cropsmillion haCropland for sugar crops (sugar beet, sugar cane)
Resources|Land Cover|Cropland|Croparea|Crops|+|Other cropsmillion haCropland for other crops (fruits, vegetables, nuts, potatoes, pulses, tropical roots)
Resources|Land Cover|Cropland|Croparea|+|Bioenergy cropsmillion haCropland for second-generation bioenergy crops (short rotation grasses, short rotation trees)
Resources|Land Cover|Cropland|Croparea|++|Irrigatedmillion haIrrigated cropland (physical area)
Resources|Land Cover|Cropland|Croparea|++|Rainfedmillion haRainfed cropland (physical area)

Author

Florian Humpenoeder

Examples

if (FALSE) { # \dontrun{
x <- reportCroparea(gdx)
} # }