Skip to content

Similar to reportDemand, but for nitrogen. reports Demand for Food, Feed, Processing, Material, Bioenergy, Seed and Supply Chain Loss

Usage

reportDemandNr(gdx, detail = FALSE)

Arguments

gdx

GDX file

detail

if detail=F, the subcategories of groups are not reported (e.g. "soybean" within "oilcrops")

Value

demand as MAgPIE object (Mt DM)

Nitrogen demand variables

NameUnitMeta
Demand|FoodMt Nr/yrNitrogen demand for food
Demand|FeedMt Nr/yrNitrogen demand for feed
Demand|ProcessingMt Nr/yrNitrogen demand for processing
Demand|BioenergyMt Nr/yrNitrogen demand for bioenergy
Demand|MaterialMt Nr/yrNitrogen demand for materials

Author

Benjamin Leon Bodirsky

Examples


  if (FALSE) { # \dontrun{
    x <- reportDemand()
  } # }