Skip to content

reports food expenditure index and food expenditure index corrected for emission costs

Usage

reportExpenditureFoodIndex(
  gdx,
  baseyear = "y2010",
  basketyear = "y2010",
  level = "regglo"
)

Arguments

gdx

GDX file

baseyear

Baseyear of the price index

basketyear

Year of reference food basket (should be in the past for comparison of different runs to have identical and comparable food basket)

level

aggregation level of returned data ("regglo" by default)

Value

Food expenditure index as MAgPIE object

Food expenditure index variables

NameUnitMeta
Prices|Food Expenditure IndexIndex 2010=100Food expenditure index (all food products)
Prices|Food Expenditure Index|Plant-based food productsIndex 2010=100Food expenditure index for plant-based products
Prices|Food Expenditure Index|Livestock food productsIndex 2010=100Food expenditure index for livestock products
Prices|Food Expenditure Index corrected for ghg costsIndex 2010=100Food expenditure index corrected for GHG costs
Prices|Agricultural Primary Products Expenditure IndexIndex 2010=100Agricultural primary products expenditure index

Author

Felicitas Beier

Examples

if (FALSE) { # \dontrun{
x <- reportPriceFoodIndex(gdx)
} # }