Skip to content

reads land cover data and deforestation data to produce future estimates of fire emissions based on extrapolating GFED data from 2003-2016

Usage

reportFireEmissions(gdx, level = "reg")

Arguments

gdx

GDX file

level

Level of regional aggregation; "reg" (regional), "glo" (global), "regglo" (regional and global)

Value

emissions as MAgPIE object (unit: Mt X/yr, plus cumulative Mt X/yr)

Fire emission variables

NameUnitMeta
Emissions|CO2|AFOLU|Land|FiresMt CO2/yrTotal CO2 emissions from fires
Emissions|CO2|AFOLU|Land|Fires|+|Forest BurningMt CO2/yrCO2 from forest fires
Emissions|CO2|AFOLU|Land|Fires|Forest Burning|+|Boreal ForestMt CO2/yrCO2 from boreal
forest fires
Emissions|CO2|AFOLU|Land|Fires|Forest Burning|+|Tropical ForestMt CO2/yrCO2 from tropical
deforestation fires
Emissions|CO2|AFOLU|Land|Fires|+|Grassland BurningMt CO2/yrCO2 from grassland/savanna
fires
Emissions|CO2|AFOLU|Land|Fires|+|Peat BurningMt CO2/yrCO2 from peat fires

Author

Michael Crawford

Examples

  if (FALSE) { # \dontrun{
    x <- reportFireEmissions(gdx, level = "glo")
  } # }