Skip to content

reports fit and error indicators compared to initial values

Usage

reportFit(gdx, type = "MAPE", level = "cell")

Arguments

gdx

GDX file

type

type of indicator. Options: R2, MAE, MPE (mean percentage error - bias), MAPE (mean absolute percentage error)

level

level at which the regional and global bias should be reported. Options "cell" or "grid"

Value

Selected error indicator

Cluster-level fit indicator variables

NameUnitMeta
Fit|Cluster|Land CoverMAPE/MAE/MPEFit indicator for overall land cover
Fit|Cluster|Land Cover|CroplandMAPE/MAE/MPEFit indicator for cropland
Fit|Cluster|Land Cover|Pastures and RangelandsMAPE/MAE/MPEFit indicator for pasture (when no range distinction)
Fit|Cluster|Land Cover|Managed pasturesMAPE/MAE/MPEFit indicator for managed pastures (when range available)
Fit|Cluster|Land Cover|RangelandsMAPE/MAE/MPEFit indicator for rangelands (when range available)
Fit|Cluster|Land Cover|Urban AreaMAPE/MAE/MPEFit indicator for urban area
Fit|Cluster|Land Cover|Other LandMAPE/MAE/MPEFit indicator for other land
Fit|Cluster|Land Cover|Forest|Natural Forest|Primary ForestMAPE/MAE/MPEFit indicator for primary forest
Fit|Cluster|Land Cover|Forest|Natural Forest|Secondary ForestMAPE/MAE/MPEFit indicator for secondary forest
Fit|Cluster|Land Cover|Forest|Planted ForestMAPE/MAE/MPEFit indicator for planted forest
Fit|Cluster|Land Cover|Cropland|{crop}MAPE/MAE/MPEFit indicator for individual crop types

Grid-level fit indicator variables

NameUnitMeta
Fit|Grid|Land CoverMAPE/MAE/MPEGrid-level fit indicator for overall land cover
Fit|Grid|Land Cover|CroplandMAPE/MAE/MPEGrid-level fit indicator for cropland
Fit|Grid|Land Cover|Pastures and RangelandsMAPE/MAE/MPEGrid-level fit indicator for pasture
Fit|Grid|Land Cover|Managed pasturesMAPE/MAE/MPEGrid-level fit indicator for managed pastures (when range available)
Fit|Grid|Land Cover|RangelandsMAPE/MAE/MPEGrid-level fit indicator for rangelands (when range available)
Fit|Grid|Land Cover|Urban AreaMAPE/MAE/MPEGrid-level fit indicator for urban area
Fit|Grid|Land Cover|Other LandMAPE/MAE/MPEGrid-level fit indicator for other land
Fit|Grid|Land Cover|Forest|Natural Forest|Primary ForestMAPE/MAE/MPEGrid-level fit indicator for primary forest
Fit|Grid|Land Cover|Forest|Natural Forest|Secondary ForestMAPE/MAE/MPEGrid-level fit indicator for secondary forest
Fit|Grid|Land Cover|Forest|Planted ForestMAPE/MAE/MPEGrid-level fit indicator for planted forest

Author

Edna Molina Bacca, Patrick v. Jeetze

Examples


  if (FALSE) { # \dontrun{
    x <- reportFit(gdx,type)
  } # }