Skip to content

reports net and gross forest area change

Usage

reportNetForestChange(gdx, level = "regglo")

Arguments

gdx

GDX file

level

An aggregation level for the spatial dimension. Can be any level available via superAggregateX.

Value

NetForestChange as magclass object (Mha per year)

Net forest change variables

NameUnitMeta
Resources|NetForestChangeMha/yrAnnual net change in total forest area

Gross forest loss variables

NameUnitMeta
Resources|GrossForestLossMha/yrAnnual gross deforested area
Resources|GrossForestLoss|+|PrimaryMha/yrAnnual gross loss of primary forest area
Resources|GrossForestLoss|+|SecondaryMha/yrAnnual gross loss of secondary forest area
Resources|GrossForestLoss|+|PlantedMha/yrAnnual gross loss of planted forest area
Resources|GrossForestLoss|Planted|Plantation|+|TimberMha/yrAnnual gross loss of timber plantation area
Resources|GrossForestLoss|Planted|Plantation|+|CO2-price ARMha/yrAnnual gross loss of CO2-price afforestation/reforestation plantation area
Resources|GrossForestLoss|Planted|Natural|+|CO2-price ARMha/yrAnnual gross loss of CO2-price afforestation/reforestation natural forest area
Resources|GrossForestLoss|Planted|Natural|+|NPI_NDC ARMha/yrAnnual gross loss of NPI/NDC afforestation/reforestation area

Gross forest gain variables

NameUnitMeta
Resources|GrossForestGainMha/yrAnnual gross expansion of forest area
Resources|GrossForestGain|+|PrimaryMha/yrAnnual gross expansion of primary forest area
Resources|GrossForestGain|+|SecondaryMha/yrAnnual gross expansion of secondary forest area
Resources|GrossForestGain|+|PlantedMha/yrAnnual gross expansion of planted forest area
Resources|GrossForestGain|Planted|Plantation|+|TimberMha/yrAnnual gross expansion of timber plantation area
Resources|GrossForestGain|Planted|Plantation|+|CO2-price ARMha/yrAnnual gross expansion of carbon plantation area through reforestation and/or afforestation with monoculture and/or non-native species
Resources|GrossForestGain|Planted|Natural|+|CO2-price ARMha/yrAnnual gross reforestation and/or afforestation area for carbon sequestration with native tree species
Resources|GrossForestGain|Planted|Natural|+|NPI_NDC ARMha/yrAnnual gross expansion of NPI/NDC afforestation/reforestation area

Author

Florian Humpenoeder

Examples

if (FALSE) { # \dontrun{
x <- reportNetForestChange(gdx)
} # }