Skip to content

Reports the Nitrogen Budgets of Croplands for future MAgPIE projections

Usage

reportNitrogenBudgetCropland(gdx, include_emissions = FALSE, level = "regglo")

Arguments

gdx

GDX file

include_emissions

TRUE also divides the N surplus into different emissions

level

aggregation level of returned data ("regglo" by default); use "grid" for 0.5 degree grid level

Nitrogen inputs variables

NameUnitMeta
Resources|Nitrogen|Cropland Budget|InputsMt Nr/yrTotal nitrogen inputs to cropland
Resources|Nitrogen|Cropland Budget|Inputs|+|FertilizerMt Nr/yrSynthetic fertilizer nitrogen applied to cropland
Resources|Nitrogen|Cropland Budget|Inputs|+|ManureMt Nr/yrManure nitrogen applied to cropland
Resources|Nitrogen|Cropland Budget|Inputs|+|BNFMt Nr/yrBiological nitrogen fixation on cropland
Resources|Nitrogen|Cropland Budget|Inputs|+|Atmospheric depositionMt Nr/yrAtmospheric nitrogen deposition on cropland
Resources|Nitrogen|Cropland Budget|Inputs|+|SeedsMt Nr/yrNitrogen from seeds

Nitrogen withdrawals variables

NameUnitMeta
Resources|Nitrogen|Cropland Budget|WithdrawalsMt Nr/yrTotal nitrogen withdrawals from cropland
Resources|Nitrogen|Cropland Budget|Withdrawals|+|HarvestMt Nr/yrNitrogen removed in harvested crops
Resources|Nitrogen|Cropland Budget|Withdrawals|+|Above-ground residuesMt Nr/yrNitrogen in above-ground crop residues
Resources|Nitrogen|Cropland Budget|Withdrawals|+|Below-ground residuesMt Nr/yrNitrogen in below-ground crop residues

Nitrogen balance variables

NameUnitMeta
Resources|Nitrogen|Cropland Budget|BalanceMt Nr/yrTotal nitrogen balance on cropland
Resources|Nitrogen|Cropland Budget|Balance|+|SurplusMt Nr/yrNitrogen surplus on cropland (inputs minus withdrawals)
Resources|Nitrogen|Cropland Budget|Balance|+|Soil organic matterMt Nr/yrNet nitrogen flow into soil organic matter (negative = release)
Resources|Nitrogen|Cropland Budget|Balance|+|Balance flowMt Nr/yrNitrogen balance flow (calibration term)

See also

Author

Benjamin Leon Bodirsky

Examples

if (FALSE) { # \dontrun{
x <- reportNitrogenBudgetCropland(gdx)
} # }