Skip to content

Internal support function to run a reporting in a try environment and properly report problems if something goes wrong without stopping the further processing in case of an error.

Usage

tryReport(report, gdx, level = "regglo", env = parent.frame())

Arguments

report

report function to be run

gdx

gdx file to report from

level

spatial level (either "regglo" for region+global, "iso" for country-level, or the file of a mapping file).

env

environment to evaluate the report in

Value

A named list with information on the outcome of the report (success, error, validationError, warning)

Author

Jan Philipp Dietrich