Function to check if the library functions work with the newest magpie version
Value
A list with three entries:
errorThese functions could not be executed properly.fineEverything was fine with these functions.
Details
This function simply tries to run all functions in the magpie library on the provided gdx file.
Examples
if (FALSE) { # \dontrun{
x <- modelstat(gdx)
} # }