reads costs entering the objective function from a MAgPIE gdx file
Arguments
- gdx
GDX file
- file
a file name the output should be written to using write.magpie
- level
Level of regional aggregation; "reg" (regional), "glo" (global), "regglo" (regional and global) or any other aggregation level defined in superAggregate
- type
either "annuity" (as it enters the objetive function) or "investment" (investment)
- sum
total costs (TRUE) or detailed costs (FALSE)