Checks whether a set of expected variable names is present in a MAgPIE report object. Variable names are normalized in that summation symbols are removed.
See also
Other Infrastructure:
metadata_comments(),
out(),
tryList(),
tryReport()
Checks whether a set of expected variable names is present in a MAgPIE report object. Variable names are normalized in that summation symbols are removed.
Other Infrastructure:
metadata_comments(),
out(),
tryList(),
tryReport()