Extracts manure used as direct combustion fuel from a MAgPIE GDX file at ISO country level. Converts from nitrogen mass (Mt N) to energy (PJ) using livestock-specific heating values and nitrogen contents from Hoyos-Sebá et al. (2024).
Extracts manure used as direct combustion fuel from a MAgPIE GDX file at ISO country level. Converts from nitrogen mass (Mt N) to energy (PJ) using livestock-specific heating values and nitrogen contents from Hoyos-Sebá et al. (2024).