Collects outputs from MAgPIE runs for FABLE Scenathon.
Arguments
- gdx
a GDX file
- file
a file name the output should be written to using write.report. If `NULL` the report is returned instead as a MAgPIE object. For the easier reporting in Scenathon tabs, a .csv file extension is recommenended.
- iso
country/region selection. Default `NULL`, i.e. all `regglo` reporting