Function to safely returns parameters. Function returns either the output or writes it to a file. Please use this function when you write own GDX output functions.
See also
Other Infrastructure:
expectVariablesPresent(),
metadata_comments(),
tryList(),
tryReport()