Skip to content

reports Demand for Food, Feed, Processing, Material, Bioenergy, Seed and Supply Chain Loss

Usage

reportDemand(gdx, detail = FALSE, agmip = FALSE, level = "regglo")

Arguments

gdx

GDX file

detail

if detail=F, the subcategories of groups are not reported (e.g. "soybean" within "oilcrops")

agmip

if agmip=T, additional sector aggregates required for agmip are reported (e.g. "AGR")

level

The level at which the report data should be aggregated.

Value

demand as MAgPIE object (Mt DM)

Demand variables

NameUnitMeta
DemandMt DM/yrTotal demand for agricultural products including food, feed, processing, material, bioenergy, seed and supply chain loss
Demand|++|CropsMt DM/yrDemand for crops including food, feed products and bioenergy (1st and 2nd generation crops)
Demand|++|Livestock productsMt DM/yrDemand for livestock products (excluding fish)
Demand|++|Secondary productsMt DM/yrDemand for secondary products (processed agricultural goods)
Demand|++|PastureMt DM/yrDemand for pasture biomass
Demand|++|Bioenergy cropsMt DM/yrDemand for second-generation bioenergy crops

Demand by use variables

NameUnitMeta
Demand|FoodMt DM/yrDemand for food consumption
Demand|FeedMt DM/yrDemand for animal feed
Demand|ProcessingMt DM/yrDemand for food processing
Demand|MaterialMt DM/yrDemand for material use (non-food, non-feed)
Demand|BioenergyMt DM/yrDemand for bioenergy production
Demand|SeedMt DM/yrDemand for seeds
Demand|Supply Chain LossMt DM/yrLosses in the supply chain

Author

Benjamin Leon Bodirsky, Isabelle Weindl

Examples


  if (FALSE) { # \dontrun{
    x <- reportDemand()
  } # }