Skip to content

reports land transition matrix with gross land-use change flows between all land types

Usage

reportLandTransitionMatrix(gdx, level = "regglo")

Arguments

gdx

GDX file

level

The aggregation level to be used ("regglo" by default)

Value

land transition matrix as MAgPIE object (Mha/yr)

Total land transition variables

NameUnitMeta
Resources|Land TransitionsMha/yrTotal gross land-use change (sum of all off-diagonal transitions)

From Cropland variables

NameUnitMeta
Resources|Land Transitions|+|From CroplandMha/yrTotal annual gross land-use change from cropland to other land types
Resources|Land Transitions|From Cropland|+|To Pastures and RangelandsMha/yrAnnual gross transition from cropland to pastures and rangelands
Resources|Land Transitions|From Cropland|+|To Urban AreaMha/yrAnnual gross transition from cropland to urban area
Resources|Land Transitions|From Cropland|+|To Other LandMha/yrAnnual gross transition from cropland to other land
Resources|Land Transitions|From Cropland|+|To ForestMha/yrAnnual gross transition from cropland to forest (sum of planted, primary, and secondary forest)
Resources|Land Transitions|From Cropland|To Forest|+|To Planted ForestMha/yrAnnual gross transition from cropland to planted forest
Resources|Land Transitions|From Cropland|To Forest|+|To Primary ForestMha/yrAnnual gross transition from cropland to primary forest (structurally zero)
Resources|Land Transitions|From Cropland|To Forest|+|To Secondary ForestMha/yrAnnual gross transition from cropland to secondary forest

From Pastures and Rangelands variables

NameUnitMeta
Resources|Land Transitions|+|From Pastures and RangelandsMha/yrTotal annual gross land-use change from pastures and rangelands to other land types
Resources|Land Transitions|From Pastures and Rangelands|+|To CroplandMha/yrAnnual gross transition from pastures and rangelands to cropland
Resources|Land Transitions|From Pastures and Rangelands|+|To Urban AreaMha/yrAnnual gross transition from pastures and rangelands to urban area
Resources|Land Transitions|From Pastures and Rangelands|+|To Other LandMha/yrAnnual gross transition from pastures and rangelands to other land
Resources|Land Transitions|From Pastures and Rangelands|+|To ForestMha/yrAnnual gross transition from pastures and rangelands to forest (sum of planted, primary, and secondary forest)
Resources|Land Transitions|From Pastures and Rangelands|To Forest|+|To Planted ForestMha/yrAnnual gross transition from pastures and rangelands to planted forest
Resources|Land Transitions|From Pastures and Rangelands|To Forest|+|To Primary ForestMha/yrAnnual gross transition from pastures and rangelands to primary forest (structurally zero)
Resources|Land Transitions|From Pastures and Rangelands|To Forest|+|To Secondary ForestMha/yrAnnual gross transition from pastures and rangelands to secondary forest

From Planted Forest variables

NameUnitMeta
Resources|Land Transitions|+|From Planted ForestMha/yrTotal annual gross land-use change from planted forest to other land types
Resources|Land Transitions|From Planted Forest|+|To CroplandMha/yrAnnual gross transition from planted forest to cropland
Resources|Land Transitions|From Planted Forest|+|To Pastures and RangelandsMha/yrAnnual gross transition from planted forest to pastures and rangelands
Resources|Land Transitions|From Planted Forest|+|To Urban AreaMha/yrAnnual gross transition from planted forest to urban area
Resources|Land Transitions|From Planted Forest|+|To Other LandMha/yrAnnual gross transition from planted forest to other land
Resources|Land Transitions|From Planted Forest|+|To ForestMha/yrAnnual gross transition from planted forest to other forest types (sum of primary and secondary forest)
Resources|Land Transitions|From Planted Forest|To Forest|+|To Primary ForestMha/yrAnnual gross transition from planted forest to primary forest (structurally zero)
Resources|Land Transitions|From Planted Forest|To Forest|+|To Secondary ForestMha/yrAnnual gross transition from planted forest to secondary forest

From Primary Forest variables

NameUnitMeta
Resources|Land Transitions|+|From Primary ForestMha/yrTotal annual gross land-use change from primary forest to other land types
Resources|Land Transitions|From Primary Forest|+|To CroplandMha/yrAnnual gross transition from primary forest to cropland
Resources|Land Transitions|From Primary Forest|+|To Pastures and RangelandsMha/yrAnnual gross transition from primary forest to pastures and rangelands
Resources|Land Transitions|From Primary Forest|+|To Urban AreaMha/yrAnnual gross transition from primary forest to urban area
Resources|Land Transitions|From Primary Forest|+|To Other LandMha/yrAnnual gross transition from primary forest to other land
Resources|Land Transitions|From Primary Forest|+|To ForestMha/yrAnnual gross transition from primary forest to other forest types (sum of planted and secondary forest)
Resources|Land Transitions|From Primary Forest|To Forest|+|To Planted ForestMha/yrAnnual gross transition from primary forest to planted forest
Resources|Land Transitions|From Primary Forest|To Forest|+|To Secondary ForestMha/yrAnnual gross transition from primary forest to secondary forest

From Secondary Forest variables

NameUnitMeta
Resources|Land Transitions|+|From Secondary ForestMha/yrTotal annual gross land-use change from secondary forest to other land types
Resources|Land Transitions|From Secondary Forest|+|To CroplandMha/yrAnnual gross transition from secondary forest to cropland
Resources|Land Transitions|From Secondary Forest|+|To Pastures and RangelandsMha/yrAnnual gross transition from secondary forest to pastures and rangelands
Resources|Land Transitions|From Secondary Forest|+|To Urban AreaMha/yrAnnual gross transition from secondary forest to urban area
Resources|Land Transitions|From Secondary Forest|+|To Other LandMha/yrAnnual gross transition from secondary forest to other land
Resources|Land Transitions|From Secondary Forest|+|To ForestMha/yrAnnual gross transition from secondary forest to other forest types (sum of planted and primary forest)
Resources|Land Transitions|From Secondary Forest|To Forest|+|To Planted ForestMha/yrAnnual gross transition from secondary forest to planted forest
Resources|Land Transitions|From Secondary Forest|To Forest|+|To Primary ForestMha/yrAnnual gross transition from secondary forest to primary forest (structurally zero)

From Urban Area variables

NameUnitMeta
Resources|Land Transitions|+|From Urban AreaMha/yrTotal annual gross land-use change from urban area to other land types
Resources|Land Transitions|From Urban Area|+|To CroplandMha/yrAnnual gross transition from urban area to cropland
Resources|Land Transitions|From Urban Area|+|To Pastures and RangelandsMha/yrAnnual gross transition from urban area to pastures and rangelands
Resources|Land Transitions|From Urban Area|+|To Other LandMha/yrAnnual gross transition from urban area to other land
Resources|Land Transitions|From Urban Area|+|To ForestMha/yrAnnual gross transition from urban area to forest (sum of planted, primary, and secondary forest)
Resources|Land Transitions|From Urban Area|To Forest|+|To Planted ForestMha/yrAnnual gross transition from urban area to planted forest
Resources|Land Transitions|From Urban Area|To Forest|+|To Primary ForestMha/yrAnnual gross transition from urban area to primary forest (structurally zero)
Resources|Land Transitions|From Urban Area|To Forest|+|To Secondary ForestMha/yrAnnual gross transition from urban area to secondary forest

From Other Land variables

NameUnitMeta
Resources|Land Transitions|+|From Other LandMha/yrTotal annual gross land-use change from other land to other land types
Resources|Land Transitions|From Other Land|+|To CroplandMha/yrAnnual gross transition from other land to cropland
Resources|Land Transitions|From Other Land|+|To Pastures and RangelandsMha/yrAnnual gross transition from other land to pastures and rangelands
Resources|Land Transitions|From Other Land|+|To Urban AreaMha/yrAnnual gross transition from other land to urban area
Resources|Land Transitions|From Other Land|+|To ForestMha/yrAnnual gross transition from other land to forest (sum of planted, primary, and secondary forest)
Resources|Land Transitions|From Other Land|To Forest|+|To Planted ForestMha/yrAnnual gross transition from other land to planted forest
Resources|Land Transitions|From Other Land|To Forest|+|To Primary ForestMha/yrAnnual gross transition from other land to primary forest (structurally zero)
Resources|Land Transitions|From Other Land|To Forest|+|To Secondary ForestMha/yrAnnual gross transition from other land to secondary forest

Author

Florian Humpenoeder

Examples


  if (FALSE) { # \dontrun{
    x <- reportLandTransitionMatrix(gdx)
  } # }