Skip to content

reports land-use

Usage

reportLandUse(gdx, level = "regglo")

Arguments

gdx

GDX file

level

The aggregation level to be used ("regglo" by default)

Value

land-use as MAgPIE object (million ha)

Total land cover variables

NameUnitMeta
Resources|Land Covermillion haTotal land cover
Resources|Land Cover|Agricultural landmillion haAgricultural land including cropland and pastures

Cropland variables

NameUnitMeta
Resources|Land Cover|+|Croplandmillion haArable land, i.e. land in bioenergy crop, food, and feed/fodder crops, permanent crops as well as other arable land (physical area)
Resources|Land Cover|Cropland|+|Cropareamillion haPhysical cropland area used for crop production
Resources|Land Cover|Cropland|+|Fallowmillion haFallow cropland
Resources|Land Cover|Cropland|+|Tree Covermillion haTrees on cropland for agroforestry

Pasture and urban variables

NameUnitMeta
Resources|Land Cover|+|Pastures and Rangelandsmillion haPasture and range land based on FAO definition of permanent meadows and pastures
Resources|Land Cover|+|Urban Areamillion haBuilt-up land associated with human settlements

Other natural land variables

NameUnitMeta
Resources|Land Cover|+|Other Landmillion haNon-forest natural land including primary non-forest, restored and recovered natural land
Resources|Land Cover|Other Land|Initialmillion haPrimary non-forest natural land without clearly visible indications of human activities
Resources|Land Cover|Other Land|Recoveredmillion haRecovered natural land due to the abandonment of agricultural or forestry land without intention for nature/biodiversity conservation
Resources|Land Cover|Other Land|Restoredmillion haIntentionally restored natural land for the purpose of nature and/or biodiversity conservation

Forest variables

NameUnitMeta
Resources|Land Cover|+|Forestmillion haSum of primary, secondary and planted forest (FAO definition)
Resources|Land Cover|Forest|+|Natural Forestmillion haNaturally regenerated forest including primary and secondary forest
Resources|Land Cover|Forest|Natural Forest|+|Primary Forestmillion haNaturally regenerated forest of native tree species where there are no clearly visible indications of human activities (FAO definition)
Resources|Land Cover|Forest|Natural Forest|+|Secondary Forestmillion haForest predominantly composed of trees established through natural regeneration excluding primary forest (based on FAO definition)
Resources|Land Cover|Forest|Natural Forest|Secondary Forest|Youngmillion haYoung secondary forest
Resources|Land Cover|Forest|Natural Forest|Secondary Forest|Maturemillion haMature secondary forest
Resources|Land Cover|Forest|+|Planted Forestmillion haForest predominantly composed of trees established through planting and/or deliberate seeding (FAO definition)
Resources|Land Cover|Forest|Planted Forest|+|Plantationsmillion haIntensively managed planted forests with one or two species, even age class, and regular spacing (FAO definition)
Resources|Land Cover|Forest|Planted Forest|Plantations|+|Timbermillion haPlantations for timber production
Resources|Land Cover|Forest|Planted Forest|Plantations|+|CO2-price ARmillion haReforestation and/or afforestation for carbon sequestration with non-native species and/or as monoculture plantation
Resources|Land Cover|Forest|Planted Forest|+|Naturalmillion haPlanted forest not classified as plantation forest
Resources|Land Cover|Forest|Planted Forest|Natural|+|CO2-price ARmillion haReforestation and/or afforestation for carbon sequestration with native tree species resembling natural vegetation
Resources|Land Cover|Forest|Planted Forest|Natural|+|NPI_NDC ARmillion haAfforestation/reforestation under national policies and NDC commitments

Author

Florian Humpenoeder, Kristine Karstens, Isabelle Weindl

Examples


  if (FALSE) { # \dontrun{
    x <- reportLandUse(gdx)
  } # }