| Name | Unit | Meta |
| Resources|Land Cover|+|Forest | million ha | Sum of primary, secondary and planted forest (FAO definition) |
| Resources|Land Cover|Forest|+|Natural Forest | million ha | Naturally regenerated forest including primary and secondary forest |
| Resources|Land Cover|Forest|Natural Forest|+|Primary Forest | million ha | Naturally regenerated forest of native tree species where there are no clearly visible indications of human activities (FAO definition) |
| Resources|Land Cover|Forest|Natural Forest|+|Secondary Forest | million ha | Forest predominantly composed of trees established through natural regeneration excluding primary forest (based on FAO definition) |
| Resources|Land Cover|Forest|Natural Forest|Secondary Forest|Young | million ha | Young secondary forest |
| Resources|Land Cover|Forest|Natural Forest|Secondary Forest|Mature | million ha | Mature secondary forest |
| Resources|Land Cover|Forest|+|Planted Forest | million ha | Forest predominantly composed of trees established through planting and/or deliberate seeding (FAO definition) |
| Resources|Land Cover|Forest|Planted Forest|+|Plantations | million ha | Intensively managed planted forests with one or two species, even age class, and regular spacing (FAO definition) |
| Resources|Land Cover|Forest|Planted Forest|Plantations|+|Timber | million ha | Plantations for timber production |
| Resources|Land Cover|Forest|Planted Forest|Plantations|+|CO2-price AR | million ha | Reforestation and/or afforestation for carbon sequestration with non-native species and/or as monoculture plantation |
| Resources|Land Cover|Forest|Planted Forest|+|Natural | million ha | Planted forest not classified as plantation forest |
| Resources|Land Cover|Forest|Planted Forest|Natural|+|CO2-price AR | million ha | Reforestation and/or afforestation for carbon sequestration with native tree species resembling natural vegetation |
| Resources|Land Cover|Forest|Planted Forest|Natural|+|NPI_NDC AR | million ha | Afforestation/reforestation under national policies and NDC commitments |