reports rural demand shares based on local consumption
Arguments
- gdx
GDX file
- type
Type of ratio that should be calculated
all: How much rural & trad demand as a share of all demand is satisfied locallytradOnly: How much rural & trad demand as a share of rural & trad demand is satisfied locallypotential: How much total gridded demand is potentially satisfied by gridded production
- level
spatial aggregation to report employment ("reg", "glo" or "regglo")
- product_aggr
sum over products if TRUE
- file
a file name the output should be written to using write.magpie