Internal support function to run a reporting in a try environment and properly report problems if something goes wrong without stopping the further processing in case of an error.
Usage
tryReport(report, gdx, level = "regglo", env = parent.frame())Value
A named list with information on the outcome of the report (success, error, validationError, warning)
See also
Other Infrastructure:
expectVariablesPresent(),
metadata_comments(),
out(),
tryList()